@@ -114,7 +114,7 @@ def report_per_read_performance(ontCalls, bgTruth, analysisPrefix, narrowedCoord
     d = defaultdict(list)
     bar = tqdm(narrowedCoordinatesList)
     for coord_tuple in bar:
-        bar.set_description(f"Read-level-{prefix_name}-{'Genome-wide' if coord_tuple is None else coord_tuple[1]}")
+        bar.set_description(f"Read-level-{prefix_name}-{genome_wide_tagname if coord_tuple is None else coord_tuple[1]}")
         if coord_tuple[1] != genome_wide_tagname:
             if not args.large_mem:
                 eval_coord_tuple = \
@@ -337,7 +337,7 @@ def import_ont_calls_for_read_level(call_encode, callfn, absoluteBGTruthCov, mul
     sites_summary = {'Dataset': dsname,
                      'Method': call_name,
                      'Sites': len(ont_call0),
-                     f'BSseq-cov{args.min_bgtruth_cov}-certain': len(absoluteBGTruthCov),
+                     f'BSseq-cov{args.min_bgtruth_cov}-certain': len(absoluteBGTruthCov) if absoluteBGTruthCov else None,
                      }
 
     if absoluteBGTruthCov:  # Filter out and keep only bg-truth cpgs, due to memory out of usage on NA19240
@@ -454,10 +454,10 @@ def compute_dist_at_region_mp(joined_bed, four_region_bed_list, region_tuple):
         'Dataset': dsname,
         'Coord': tagname,
         'Total': num_total,
-        'Singletons': num_singleton,
-        'Non-singletons': num_nonsingleton,
-        'Concordant': num_concordant,
-        'Discordant': num_discordant
+        sing_tagname: num_singleton,
+        nonsing_tagname: num_nonsingleton,
+        concord_tagname: num_concordant,
+        discord_tagname: num_discordant
     }
 
     logger.debug(
@@ -529,7 +529,7 @@ def parse_arguments():
                         required=True)
     parser.add_argument('--bgtruth', type=str,
                         help="background truth file <encode-type>:<file-name>;<file-name>, encode-type can be 'encode' or 'bismark'",
-                        required=True)
+                        default=None)
     parser.add_argument('--genome-annotation', type=str,
                         help='genome annotation dir, contain BED files such as singleton, nonsingleton, etc.',
                         default=None)
@@ -737,7 +737,7 @@ if __name__ == '__main__':
     else:
         absoluteBGTruth = None
         absoluteBGTruthCov = None
-        raise Exception("Can not get BS-seq")
+        logger.info("WARN: Can not get BS-seq")
 
     ## Narrow down to BG-Truth if there BG-Truth is available
     ontCallWithinBGTruthDict = defaultdict()  # name->call
